@@ -17,7 +17,7 @@ def cli():
 @click.argument('amount')
 @click.option('--chain', default='ETH', help='The destination chain. Defaults to ETH.')
 @click.option('--currency', default='USD', help='The amount currency to transfer. Defaults to USD.')
-def create_blockchain_transfer(walletid, address, amount, currency, chain):
+def transfer_create_blockchain(walletid, address, amount, currency, chain):
     """Create transfers from a wallet to blockchain address.
 
     WALLETID the source wallet id.\n
@@ -30,22 +30,30 @@ def create_blockchain_transfer(walletid, address, amount, currency, chain):
     amount = api.Money(amount, currency)
 
     c = getClient()
-    transfer = c.createTransfer(source, destination, amount)
+    transfer = c.create_transfer(source, destination, amount)
 
     print(transfer)
 
 @click.command()
 @click.argument('id')
-def get_transfer(id):
+def transfer_get(id):
     """Get info about transfers.
 
     ID the unique identifier of the transfer.
     """
     c = getClient()
-    transfer = c.getTransfer(id)
+    transfer = c.get_transfer(id)
     
     print(transfer)
 
+@click.command()
+def configuration_get():
+    """Get global CPS configuration"""
+    c = getClient()
+    config = c.get_configuration(id)
+    
+    print(config)
+
 
 def getClient():
     API_KEY = os.environ['CPS_API_KEY']
@@ -53,8 +61,9 @@ def getClient():
 
 
 def run():
-    cli.add_command(create_blockchain_transfer)
-    cli.add_command(get_transfer)
+    cli.add_command(transfer_create_blockchain)
+    cli.add_command(transfer_get)
+    cli.add_command(configuration_get)
 
     cli()
 
